@@ -327,6 +327,8 @@ random data taken from C</dev/random> (UNIX) or C<CryptGenRandom> (Win32).
 
 =head2 import_key
 
+Loads private or public key in DER or PEM format (password protected keys are not supported).
+
   $pk->import_key($priv_or_pub_key_filename);
   #or
   $pk->import_key(\$buffer_containing_priv_or_pub_key);
@@ -430,18 +432,18 @@ random data taken from C</dev/random> (UNIX) or C<CryptGenRandom> (Win32).
 
 =head2 size
 
- my $size = $pk->is_private;
+ my $size = $pk->size;
  # returns key size in bytes or undef if no key loaded
 
 =head2 key2hash
 
  my $hash = $pk->key2hash;
- 
+
  # returns hash like this (or undef if no key loaded):
  {
    type => 1,   # integer: 1 .. private, 0 .. public
    size => 256, # integer: key size in bytes
-   # all the rest are hex strings  
+   # all the rest are hex strings
    e  => "10001", #public exponent
    d  => "9ED5C3D3F866E06957CA0E9478A273C39BBDA4EEAC5B...", #private exponent
    N  => "D0A5CCCAE03DF9C2F5C4C8C0CE840D62CDE279990DC6...", #modulus
@@ -451,3 +453,11 @@ random data taken from C</dev/random> (UNIX) or C<CryptGenRandom> (Win32).
    dP => "486F142FEF0A1F53269AC43D2EE4D263E2841B60DA36...", #d mod (p - 1) CRT param
    dQ => "4597284B2968B72C4212DB7E8F24360B987B80514DA9...", #d mod (q - 1) CRT param
  }
+
+=head1 SEE ALSO
+
+=over
+
+=item * L<https://en.wikipedia.org/wiki/RSA_%28algorithm%29|https://en.wikipedia.org/wiki/RSA_%28algorithm%29>
+
+=back
